Class: Vellum::SlimDeploymentRead
- Inherits:
-
Object
- Object
- Vellum::SlimDeploymentRead
- Defined in:
- lib/vellum_ai/types/slim_deployment_read.rb
Overview
A subset of a Prompt Deployment's full details.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
- #created ⇒ DateTime readonly
-
#description ⇒ String
readonly
A human-readable description of the deployment.
-
#environment ⇒ Vellum::EnvironmentEnum
readonly
Deprecated.
- #id ⇒ String readonly
- #input_variables ⇒ Array<Vellum::VellumVariable> readonly
-
#label ⇒ String
readonly
A human-readable label for the deployment.
- #last_deployed_on ⇒ DateTime readonly
-
#name ⇒ String
readonly
A name that uniquely identifies this deployment within its workspace.
-
#status ⇒ Object
readonly
PENDING_DELETION- Pending Deletion.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(id:, created:, label:, name:, status: OMIT, environment: OMIT, last_deployed_on:, input_variables:, description: OMIT, additional_properties: nil) ⇒ Vellum::SlimDeploymentRead constructor
- #to_json ⇒ String
Constructor Details
#initialize(id:, created:, label:, name:, status: OMIT, environment: OMIT, last_deployed_on:, input_variables:, description: OMIT, additional_properties: nil) ⇒ Vellum::SlimDeploymentRead
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 56 def initialize(id:, created:, label:, name:, status: OMIT, environment: OMIT, last_deployed_on:, input_variables:, description: OMIT, additional_properties: nil) @id = id @created = created @label = label @name = name @status = status if status != OMIT @environment = environment if environment != OMIT @last_deployed_on = last_deployed_on @input_variables = input_variables @description = description if description != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "created": created, "label": label, "name": name, "status": status, "environment": environment, "last_deployed_on": last_deployed_on, "input_variables": input_variables, "description": description }.reject do | _k, v | v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
35 36 37 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 35 def additional_properties @additional_properties end |
#created ⇒ DateTime (readonly)
16 17 18 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 16 def created @created end |
#description ⇒ String (readonly)
Returns A human-readable description of the deployment.
33 34 35 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 33 def description @description end |
#environment ⇒ Vellum::EnvironmentEnum (readonly)
Returns Deprecated. The value returned will always be 'PRODUCTION'.
27 28 29 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 27 def environment @environment end |
#id ⇒ String (readonly)
14 15 16 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 14 def id @id end |
#input_variables ⇒ Array<Vellum::VellumVariable> (readonly)
31 32 33 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 31 def input_variables @input_variables end |
#label ⇒ String (readonly)
Returns A human-readable label for the deployment.
18 19 20 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 18 def label @label end |
#last_deployed_on ⇒ DateTime (readonly)
29 30 31 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 29 def last_deployed_on @last_deployed_on end |
#name ⇒ String (readonly)
Returns A name that uniquely identifies this deployment within its workspace.
20 21 22 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 20 def name @name end |
#status ⇒ Object (readonly)
PENDING_DELETION- Pending Deletion
25 26 27 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 25 def status @status end |
Class Method Details
.from_json(json_object:) ⇒ Vellum::SlimDeploymentRead
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 75 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] created = unless parsed_json["created"].nil? DateTime.parse(parsed_json["created"]) else nil end label = parsed_json["label"] name = parsed_json["name"] status = parsed_json["status"] environment = parsed_json["environment"] last_deployed_on = unless parsed_json["last_deployed_on"].nil? DateTime.parse(parsed_json["last_deployed_on"]) else nil end input_variables = parsed_json["input_variables"]&.map do | item | item = item.to_json Vellum::VellumVariable.from_json(json_object: item) end description = parsed_json["description"] new( id: id, created: created, label: label, name: name, status: status, environment: environment, last_deployed_on: last_deployed_on, input_variables: input_variables, description: description, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 123 def self.validate_raw(obj:) obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.created.is_a?(DateTime) != false || raise("Passed value for field obj.created is not the expected type, validation failed.") obj.label.is_a?(String) != false || raise("Passed value for field obj.label is not the expected type, validation failed.") obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.status&.is_a?(Vellum::EntityStatus) != false || raise("Passed value for field obj.status is not the expected type, validation failed.") obj.environment&.is_a?(Vellum::EnvironmentEnum) != false || raise("Passed value for field obj.environment is not the expected type, validation failed.") obj.last_deployed_on.is_a?(DateTime) != false || raise("Passed value for field obj.last_deployed_on is not the expected type, validation failed.") obj.input_variables.is_a?(Array) != false || raise("Passed value for field obj.input_variables is not the expected type, validation failed.") obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") end |
Instance Method Details
#to_json ⇒ String
114 115 116 |
# File 'lib/vellum_ai/types/slim_deployment_read.rb', line 114 def to_json @_field_set&.to_json end |