Class: Vellum::VellumCodeResourceDefinition

Inherits:
Object
  • Object
show all
Defined in:
lib/vellum_ai/types/vellum_code_resource_definition.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(name:, module_:, exclude_from_monitoring: OMIT, id:, additional_properties: nil) ⇒ Vellum::VellumCodeResourceDefinition

Parameters:

  • name (String)
  • module_ (Array<String>) —

    The module that this resource is defined in.

  • exclude_from_monitoring (Boolean) (defaults to: OMIT) —

    Whether this node should be excluded from monitoring views.

  • id (String)
  • additional_properties (OpenStruct) (defaults to: nil) —

    Additional properties unmapped to the current class definition



29
30
31
32
33
34
35
36
37
38
# File 'lib/vellum_ai/types/vellum_code_resource_definition.rb', line 29

def initialize(name:, module_:, exclude_from_monitoring: OMIT, id:, additional_properties: nil)
  @name = name
  @module_ = module_
  @exclude_from_monitoring = exclude_from_monitoring if exclude_from_monitoring != OMIT
  @id = id
  @additional_properties = additional_properties
  @_field_set = { "name": name, "module": module_, "exclude_from_monitoring": exclude_from_monitoring, "id": id }.reject do | _k, v |
  v == OMIT
end
end

Instance Attribute Details

#additional_properties ⇒ OpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct) —

    Additional properties unmapped to the current class definition



16
17
18
# File 'lib/vellum_ai/types/vellum_code_resource_definition.rb', line 16

def additional_properties
  @additional_properties
end

#exclude_from_monitoring ⇒ Boolean (readonly)

Returns Whether this node should be excluded from monitoring views.

Returns:

  • (Boolean) —

    Whether this node should be excluded from monitoring views.



12
13
14
# File 'lib/vellum_ai/types/vellum_code_resource_definition.rb', line 12

def exclude_from_monitoring
  @exclude_from_monitoring
end

#id ⇒ String (readonly)

Returns:

  • (String)


14
15
16
# File 'lib/vellum_ai/types/vellum_code_resource_definition.rb', line 14

def id
  @id
end

#module_ ⇒ Array<String> (readonly)

Returns The module that this resource is defined in.

Returns:

  • (Array<String>) —

    The module that this resource is defined in.



10
11
12
# File 'lib/vellum_ai/types/vellum_code_resource_definition.rb', line 10

def module_
  @module_
end

#name ⇒ String (readonly)

Returns:

  • (String)


8
9
10
# File 'lib/vellum_ai/types/vellum_code_resource_definition.rb', line 8

def name
  @name
end

Class Method Details

.from_json(json_object:) ⇒ Vellum::VellumCodeResourceDefinition

Parameters:

  • json_object (String)

Returns:



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/vellum_ai/types/vellum_code_resource_definition.rb', line 43

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  name = parsed_json["name"]
  module_ = parsed_json["module"]
  exclude_from_monitoring = parsed_json["exclude_from_monitoring"]
  id = parsed_json["id"]
  new(
    name: name,
    module_: module_,
    exclude_from_monitoring: exclude_from_monitoring,
    id: id,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Parameters:

  • obj (Object)

Returns:

  • (Void)


70
71
72
73
74
75
# File 'lib/vellum_ai/types/vellum_code_resource_definition.rb', line 70

def self.validate_raw(obj:)
  obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.module_.is_a?(Array) != false || raise("Passed value for field obj.module_ is not the expected type, validation failed.")
  obj.exclude_from_monitoring&.is_a?(Boolean) != false || raise("Passed value for field obj.exclude_from_monitoring is not the expected type, validation failed.")
  obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
end

Instance Method Details

#to_json ⇒ String

Returns:

  • (String)


61
62
63
# File 'lib/vellum_ai/types/vellum_code_resource_definition.rb', line 61

def to_json
  @_field_set&.to_json
end